Examples
============

Here are some simple examples that will show how to initialise an OCBoundary
object, find a trustworthy open-closed boundary, convert between AACGM and OCB
coordinates, and more.

.. toctree::

   examples/ex_init.rst
   examples/ex_rec.rst
   examples/ex_convert.rst
   examples/ex_dmsp.rst
   examples/ex_general.rst
   examples/ex_vector.rst
